@@ -401,6 +401,7 @@ class ColorfulStreamHandler(logging.StreamHandler):
     show_file: bool = True
     show_line: bool = True
     show_func: bool = True
+    show_logger_name: bool = True
     file_color: "Colors" = Colors.MAGENTA_F
 
     show_process_name: bool = False
@@ -462,6 +463,9 @@ class ColorfulStreamHandler(logging.StreamHandler):
         """
             Get File and line detail
         """
+        logger_name = get_inner_detail([
+            (self.show_logger_name, record.name),
+        ])
         file_detail = get_inner_detail([
             (self.show_file, "/".join(record.pathname.split("/")[-self.file_depth:])),
             (self.show_line, record.lineno),
@@ -469,7 +473,8 @@ class ColorfulStreamHandler(logging.StreamHandler):
         function_detail = get_inner_detail([
             (self.show_func, record.module + "()"),
         ])
-        return get_outer_detail([file_detail, function_detail])
+
+        return get_outer_detail([logger_name, file_detail, function_detail])
 
     def get_level(self, record):
         """
@@ -508,7 +513,6 @@ class ColorfulStreamHandler(logging.StreamHandler):
         except Exception:
             self.handleError(record)
 
-
 # def set_logger():
 #     """
 #         For get logger
